/*
 * The MIT License
 *
 * Copyright 2012 Massive Dynamics.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */
package biz.massivedynamics.sourcery.management;

import biz.massivedynamics.sourcery.resource.Resource;

/**
 * An abstract class that manages a resource
 *
 * @author Cruz Bishop
 * @version 1.0.0.0
 * @param <T> The resource to use
 */
public abstract class ResourceManager<T> {
    
    /**
     * Loads the resource
     * 
     * @return The resource
     * @since 1.0.0.0
     */
    public abstract T load();
    
    /**
     * Saves the resource
     * 
     * @param resource The resource
     * @since 1.0.0.0
     */
    public abstract void save(T resource);
    
    /**
     * Gets the default resource
     * 
     * @return The default resource
     * @since 1.0.0.0
     */
    public abstract T getDefault();
    
}
